==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/hr/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Ovaj korisnik se može prijaviti',
    'activated_disabled_help_text' => 'Ne možete mijenjati status aktivacije za svoj vlastiti račun.',
    'assets_user'       => 'Imovina dodijeljena za: ime',
    'bulk_update_warn'	=> 'Namjeravate uređivati ​​svojstva korisnika: user_count. Imajte na umu da ne možete mijenjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti korisnik.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'current_assets'    => 'Aktiva koji su trenutačno prijavljeni ovom korisniku',
    'clone'             => 'Korisnik klona',
    'contact_user'      => 'Ime kontakta',
    'edit'              => 'Uređivanje korisnika',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Povijest za: ime',
	'info'				=> 'Informacije',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Zadnja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) bit će postavljena za sve uvezene korisnike.',
    'print_assigned'    => 'Ispiši sve dodijeljeno',
    'software_user'     => 'Softver je provjeren na: ime',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Prikaži korisnika: ime',
    'usercsv'           => 'CSV datoteku',
    'two_factor_admin_optin_help' => 'Vaše trenutačne postavke administracije omogućuju selektivnu provedbu autentikacije dvogritera.',
    'two_factor_enrolled' => '2FA uređaj upisan',
    'two_factor_active'   => '2FA aktivno',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/hr/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ovaj korisnik se može prijaviti',
    'activated_disabled_help_text' => 'Ne možete mijenjati status aktivacije za svoj vlastiti račun.',
    'assets_user'       => 'Imovina dodijeljena za: ime',
    'bulk_update_warn'	=> 'Namjeravate uređivati ​​svojstva korisnika: user_count. Imajte na umu da ne možete mijenjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti korisnik.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućuje ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna ostat će nepromijenjena.',
    'current_assets'    => 'Aktiva koji su trenutačno prijavljeni ovom korisniku',
    'clone'             => 'Korisnik klona',
    'contact_user'      => 'Ime kontakta',
    'edit'              => 'Uređivanje korisnika',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Povijest za: ime',
    'info'				=> 'Informacije',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Zadnja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) bit će postavljena za sve uvezene korisnike.',
    'print_assigned'    => 'Ispiši sve dodijeljeno',
    'software_user'     => 'Softver je provjeren na: ime',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Prikaži korisnika: ime',
    'usercsv'           => 'CSV datoteku',
    'two_factor_admin_optin_help' => 'Vaše trenutačne postavke administracije omogućuju selektivnu provedbu autentikacije dvogritera.',
    'two_factor_enrolled' => '2FA uređaj upisan',
    'two_factor_active'   => '2FA aktivno',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
